# URtoday  

## A program to rate your days.  

[Github](https://github.com/poyynt/urtoday)  
[PyPI](https://pypi.org/project/urtoday)

### To execute:  
#### Rate:  
Run `urtoday` in a shell.  
#### Get Overview:  
Run `urtoday-overview` in a shell.  
